import{S as i,i as c,s as _,o as m,q as p,u as r,v as u,w as $,M as d,J as g,K as b,L as h,D as y}from"./index.9fc31042.js";import{T}from"./Tabs.d63196c5.js";function q(n){let s;const a=n[1].default,e=d(a,n,n[3],null);return{c(){e&&e.c()},m(t,o){e&&e.m(t,o),s=!0},p(t,o){e&&e.p&&(!s||o&8)&&g(e,a,t,t[3],s?h(a,t[3],o,null):b(t[3]),null)},i(t){s||(r(e,t),s=!0)},o(t){u(e,t),s=!1},d(t){e&&e.d(t)}}}function v(n){let s,a;return s=new T({props:{style:n[0],$$slots:{default:[q]},$$scope:{ctx:n}}}),s.$on("change",n[2]),{c(){m(s.$$.fragment)},m(e,t){p(s,e,t),a=!0},p(e,[t]){const o={};t&1&&(o.style=e[0]),t&8&&(o.$$scope={dirty:t,ctx:e}),s.$set(o)},i(e){a||(r(s.$$.fragment,e),a=!0)},o(e){u(s.$$.fragment,e),a=!1},d(e){$(s,e)}}}function w(n,s,a){let{$$slots:e={},$$scope:t}=s,{style:o=""}=s;function f(l){y.call(this,n,l)}return n.$$set=l=>{"style"in l&&a(0,o=l.style),"$$scope"in l&&a(3,t=l.$$scope)},[o,e,f,t]}class C extends i{constructor(s){super(),c(this,s,w,v,_,{style:0})}}var J=C;const K=["static"];export{J as Component,K as modes};
