import{S as l,i as o,s as r,e as u,d,a as c,b as f,f as m,g as p,n as i,h as v}from"./index.9fc31042.js";function x(n){let e,s;return{c(){e=u("div"),s=d(n[0]),c(e,"class","input-model3D-example")},m(a,t){f(a,e,t),m(e,s)},p(a,[t]){t&1&&p(s,a[0])},i,o:i,d(a){a&&v(e)}}}function _(n,e,s){let{value:a}=e;return n.$$set=t=>{"value"in t&&s(0,a=t.value)},[a]}class h extends l{constructor(e){super(),o(this,e,_,x,r,{value:0})}}var g=h;export{g as E};
