import{S as c,i as o,s as f,e as v,a as h,R as y,b as g,n as r,h as w,z as d,o as b,q as k,u as M,v as q,w as C,D}from"./index.9fc31042.js";function H(n){let e;return{c(){e=v("div"),h(e,"class","output-markdown prose"),y(e,"max-width","100%")},m(a,t){g(a,e,t),e.innerHTML=n[0]},p(a,[t]){t&1&&(e.innerHTML=a[0])},i:r,o:r,d(a){a&&w(e)}}}function L(n,e,a){let{value:t}=e,{style:s=""}=e;const l=d();return n.$$set=u=>{"value"in u&&a(0,t=u.value),"style"in u&&a(1,s=u.style)},n.$$.update=()=>{n.$$.dirty&1&&l("change")},[t,s]}class S extends c{constructor(e){super(),o(this,e,L,H,f,{value:0,style:1})}}function T(n){let e,a;return e=new S({props:{value:n[0],style:n[1]}}),e.$on("change",n[4]),{c(){b(e.$$.fragment)},m(t,s){k(e,t,s),a=!0},p(t,[s]){const l={};s&1&&(l.value=t[0]),s&2&&(l.style=t[1]),e.$set(l)},i(t){a||(M(e.$$.fragment,t),a=!0)},o(t){q(e.$$.fragment,t),a=!1},d(t){C(e,t)}}}function x(n,e,a){let{label:t}=e,{value:s=""}=e,{default_value:l}=e,{style:u=""}=e;const m=d();l&&(s=l);function _(i){D.call(this,n,i)}return n.$$set=i=>{"label"in i&&a(2,t=i.label),"value"in i&&a(0,s=i.value),"default_value"in i&&a(3,l=i.default_value),"style"in i&&a(1,u=i.style)},n.$$.update=()=>{n.$$.dirty&4&&m("change")},[s,u,t,l,_]}class z extends c{constructor(e){super(),o(this,e,x,T,f,{label:2,value:0,default_value:3,style:1})}}var R=z;const j=["static"];export{R as Component,j as modes};
