import{S as u,i as _,s as d,e as b,k as h,d as w,F as f,a as o,t as m,b as x,f as c,g as y,n as g,h as v}from"./index.9fc31042.js";function k(l){let e,t,s,i,n;return{c(){e=b("div"),t=b("img"),i=h(),n=w(l[0]),f(t.src,s=l[1])||o(t,"src",s),o(t,"alt",""),o(t,"class","mr-2 h-[12px] w-[12px] opacity-50"),o(e,"class","absolute left-0 top-0 py-1 px-2 rounded-br-lg shadow-sm text-xs text-gray-500 flex items-center pointer-events-none bg-white z-20 border-b border-r border-gray-100"),m(e,"sr-only",!l[2])},m(a,r){x(a,e,r),c(e,t),c(e,i),c(e,n)},p(a,[r]){r&2&&!f(t.src,s=a[1])&&o(t,"src",s),r&1&&y(n,a[0]),r&4&&m(e,"sr-only",!a[2])},i:g,o:g,d(a){a&&v(e)}}}function p(l,e,t){let{label:s=null}=e,{image:i=void 0}=e,{show_label:n=!0}=e;return l.$$set=a=>{"label"in a&&t(0,s=a.label),"image"in a&&t(1,i=a.image),"show_label"in a&&t(2,n=a.show_label)},[s,i,n]}class B extends u{constructor(e){super(),_(this,e,p,k,d,{label:0,image:1,show_label:2})}}export{B};
