import{S as u,i as c,s as _,e as f,a as r,F as l,b as o,n as m,h as g}from"./index.9fc31042.js";function d(i){let e,s;return{c(){e=f("img"),r(e,"class","input-image-example h-24 max-w-none"),l(e.src,s=i[1]+i[0])||r(e,"src",s)},m(a,t){o(a,e,t)},p(a,[t]){t&3&&!l(e.src,s=a[1]+a[0])&&r(e,"src",s)},i:m,o:m,d(a){a&&g(e)}}}function v(i,e,s){let{value:a}=e,{samples_dir:t}=e;return i.$$set=n=>{"value"in n&&s(0,a=n.value),"samples_dir"in n&&s(1,t=n.samples_dir)},[a,t]}class p extends u{constructor(e){super(),c(this,e,v,d,_,{value:0,samples_dir:1})}}var x=p;export{x as E};
