.samples-holder:not(.gallery){--tw-shadow:0 1px 3px 0 rgb(0 0 0 / .1), 0 1px 2px -1px rgb(0 0 0 / .1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.samples-holder:not(.gallery) .samples-table{border-radius:.25rem}.samples-holder:not(.gallery) .dark .samples-table{--tw-bg-opacity:1;background-color:rgb(55 65 81 / var(--tw-bg-opacity))}.samples-holder:not(.gallery) .samples-table thead{--tw-border-opacity:1;border-color:rgb(209 213 219 / var(--tw-border-opacity))}.samples-holder:not(.gallery) .samples-table .dark thead{--tw-border-opacity:1;border-color:rgb(75 85 99 / var(--tw-border-opacity))}.samples-holder:not(.gallery) .samples-table tbody tr:hover{--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))}.samples-holder:not(.gallery) .samples-table .dark tbody tr:hover{--tw-bg-opacity:1;background-color:rgb(185 28 28 / var(--tw-bg-opacity))}.samples-holder .samples-gallery .sample{--tw-shadow:0 1px 3px 0 rgb(0 0 0 / .1), 0 1px 2px -1px rgb(0 0 0 / .1);--tw-shadow-colored:0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.samples-holder .samples-gallery .sample:hover{--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))}.samples-table tr.selected{font-weight:600}.page{border-radius:.25rem;--tw-bg-opacity:1;background-color:rgb(243 244 246 / var(--tw-bg-opacity));padding:.25rem .5rem}.dark .page{--tw-bg-opacity:1;background-color:rgb(55 65 81 / var(--tw-bg-opacity))}
