import{S as _,i as b,s as d,e as S,a as q,b as p,J as $,K as g,L as h,u as i,v as f,h as k,j as w,x as I,y as j,Z as y,I as A,C as B,M as C,o as D,q as J,w as K}from"./index.9fc31042.js";import{a as L}from"./Tabs.d63196c5.js";function m(l){let s,a;const e=l[5].default,t=C(e,l,l[4],null);return{c(){s=S("div"),t&&t.c(),q(s,"class","p-2 border-2 border-t-0 border-gray-200 relative")},m(n,o){p(n,s,o),t&&t.m(s,null),a=!0},p(n,o){t&&t.p&&(!a||o&16)&&$(t,e,n,n[4],a?h(e,n[4],o,null):g(n[4]),null)},i(n){a||(i(t,n),a=!0)},o(n){f(t,n),a=!1},d(n){n&&k(s),t&&t.d(n)}}}function M(l){let s,a,e=l[0]===l[1]&&m(l);return{c(){e&&e.c(),s=w()},m(t,n){e&&e.m(t,n),p(t,s,n),a=!0},p(t,[n]){t[0]===t[1]?e?(e.p(t,n),n&1&&i(e,1)):(e=m(t),e.c(),i(e,1),e.m(s.parentNode,s)):e&&(I(),f(e,1,1,()=>{e=null}),j())},i(t){a||(i(e),a=!0)},o(t){f(e),a=!1},d(t){e&&e.d(t),t&&k(s)}}}function N(l,s,a){let e,{$$slots:t={},$$scope:n}=s,{name:o}=s;const u={},{register_tab:T,unregister_tab:v,selected_tab:c}=y(L);return A(l,c,r=>a(0,e=r)),T({name:o,id:u}),B(()=>{v({name:o,id:u})}),l.$$set=r=>{"name"in r&&a(3,o=r.name),"$$scope"in r&&a(4,n=r.$$scope)},[e,u,c,o,n,t]}class Z extends _{constructor(s){super(),b(this,s,N,M,d,{name:3})}}function z(l){let s;const a=l[1].default,e=C(a,l,l[2],null);return{c(){e&&e.c()},m(t,n){e&&e.m(t,n),s=!0},p(t,n){e&&e.p&&(!s||n&4)&&$(e,a,t,t[2],s?h(a,t[2],n,null):g(t[2]),null)},i(t){s||(i(e,t),s=!0)},o(t){f(e,t),s=!1},d(t){e&&e.d(t)}}}function E(l){let s,a;return s=new Z({props:{name:l[0],$$slots:{default:[z]},$$scope:{ctx:l}}}),{c(){D(s.$$.fragment)},m(e,t){J(s,e,t),a=!0},p(e,[t]){const n={};t&1&&(n.name=e[0]),t&4&&(n.$$scope={dirty:t,ctx:e}),s.$set(n)},i(e){a||(i(s.$$.fragment,e),a=!0)},o(e){f(s.$$.fragment,e),a=!1},d(e){K(s,e)}}}function F(l,s,a){let{$$slots:e={},$$scope:t}=s,{label:n}=s;return l.$$set=o=>{"label"in o&&a(0,n=o.label),"$$scope"in o&&a(2,t=o.$$scope)},[n,e,t]}class G extends _{constructor(s){super(),b(this,s,F,E,d,{label:0})}}var P=G;const Q=["static"];export{P as Component,Q as modes};
